;; longhorn/theme.jl

;; Copyright (C) 2004 Darius Svoba <darrukas@one.lt>

;; This theme is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.
;;

;; configuration options

;; main options
(defgroup longhorn "longhorn Theme"
  :group appearance)

(defcustom longhorn:title-font 
  (get-font "-b&h-lucida-bold-r-normal-*-*-120-*-*-p-*-iso8859-1")
  "Font for window titles."
  :group (appearance longhorn)
  :type font)

(defcustom longhorn:title_height '30
  "Text is justified in window titles."
  :type (get-int)
  :group (appearance longhorn))

(let*
    ( ;; *** fonts & colors ********************************************
     (font-colors longhorn:title-font)
     
     ;; Buttons
     (close-image (list (make-image "button-close-inactive.png")
			(make-image "button-close.png")
			(make-image "button-close.png")
			(make-image "button-close-pressed.png")))
     (max-image (list (make-image "button-max-inactive.png")
		      (make-image "button-max.png")
		      (make-image "button-max.png")
		      (make-image "button-max-pressed.png")))
     (menu-image (list (make-image "button-inactive-template.png")
		       (make-image "button-normal-template.png")
		       (make-image "button-normal-template.png")
		       (make-image "button-pressed-template.png")))
     (min-image (list (make-image "button-min-inactive.png")
		      (make-image "button-min.png")
		      (make-image "button-min.png")
		      (make-image "button-min-pressed.png")))
     
     ;; Title
     (title-image (list (make-image "shade-bar.png")
			(make-image "title-bar.png")))
     
     ;; Top
     (top-left-image (list (make-image "left-side.png")
			   (make-image "left-side.png")))
     (top-right-image (list (make-image "right-side.png")
			    (make-image "right-side.png")))
     (top-left-shaded-image (list (make-image "left-shade.png")
				  (make-image "left-shade.png")))
     (top-right-shaded-image (list (make-image "right-shade.png")
				   (make-image "right-shade.png")))
     
     ;; bottom
     (bottom-left-image (list (make-image "bottom-left.png")
			      (make-image "bottom-left.png")))
     (bottom-middle-image (list (make-image "bottom.png")
				(make-image "bottom.png")))
     (bottom-right-image (list (make-image "bottom-right.png")
			       (make-image "bottom-right.png")))
     
     ;; Border
     (border-left-image (list (make-image "left-edge.png")
			      (make-image "left-edge.png")))
     (border-right-image (list (make-image "right-edge.png")
			       (make-image "right-edge.png")))
     
     (frame `(
	      ((background . ,top-left-image)
	       (top-edge . ,(- 0 longhorn:title_height))
	       (left-edge . -4)
	       (height . ,longhorn:title_height)
	       (class . title))
	      ((background . ,title-image)
	       (foreground . ,font-colors)
	       (text . ,window-name)
	       (x-justify . center)
	       (y-justify . center)
	       (left-edge . 18)
	       (right-edge . 52)
	       (top-edge . ,(- 0 longhorn:title_height))
	       (height . ,longhorn:title_height)
	       (cursor . left_ptr)
	       (class . title))
	      ((background . ,top-right-image)
	       (right-edge . -4)
	       (top-edge . ,(- 0 longhorn:title_height))
	       (height . ,longhorn:title_height)
	       (class . title))
	      
	      ((background . ,border-left-image)
	       (left-edge . -4)
	       (top-edge . 0)
	       (bottom-edge . 0)
	       (class . left-border))
	      ((background . ,border-right-image)
	       (right-edge . -4)
	       (top-edge . 0)
	       (bottom-edge . 0)
	       (class . right-border))
	      
	      ((background . ,bottom-left-image)
	       (left-edge . -4)
	       (bottom-edge . -4)
	       (class . bottom-left-corner))
	      ((background . ,bottom-middle-image)
	       (left-edge . +6)
	       (right-edge . +6)
	       (bottom-edge . -4)
	       (class . bottom-border))
	      ((background . ,bottom-right-image)
	       (right-edge . -4)
	       (bottom-edge . -4)
	       (class . bottom-right-corner))
	      
	      ((background . ,close-image)
	       (right-edge . 1)
	       (top-edge . ,(- 0 longhorn:title_height))
	       (height . ,longhorn:title_height)
	       (cursor . left_ptr)
	       (class . close-button))
	      ((background . ,max-image)
	       (right-edge . 20)
	       (top-edge . ,(- 0 longhorn:title_height))
	       (height . ,longhorn:title_height)
	       (cursor . left_ptr)
	       (class . maximize-button))
	      ((background . ,min-image)
	       (right-edge . 39)
	       (top-edge . ,(- 0 longhorn:title_height))
	       (height . ,longhorn:title_height)
	       (cursor . left_ptr)
	       (class . iconify-button))
	      ((background . ,menu-image)
	       (left-edge . 1)
	       (top-edge . ,(- 0 longhorn:title_height))
	       (height . ,longhorn:title_height)
	       (cursor . hand2)
	       (class . menu-button))
	      ))
     
     (shaded-frame `(
		     ((background . ,top-left-shaded-image)
		      (top-edge . ,(- 0 longhorn:title_height))
		      (left-edge . -4)
		      (height . ,longhorn:title_height)
		      (class . title))
		     ((background . ,title-image)
		      (foreground . ,font-colors)
		      (text . ,window-name)
		      (x-justify . center)
		      (y-justify . center)
		      (left-edge . 18)
		      (right-edge . 52)
		      (top-edge . ,(- 0 longhorn:title_height))
		      (height . ,longhorn:title_height)
		      (cursor . left_ptr)
		      (class . title))
		     ((background . ,top-right-shaded-image)
		      (right-edge . -4)
		      (top-edge . ,(- 0 longhorn:title_height))
		      (height . ,longhorn:title_height)
		      (class . title))
		     
		     ((background . ,close-image)
		      (right-edge . 1)
		      (top-edge . ,(- 0 longhorn:title_height))
		      (height . ,longhorn:title_height)
		      (cursor . left_ptr)
		      (class . close-button))
		     ((background . ,max-image)
		      (right-edge . 20)
		      (top-edge . ,(- 0 longhorn:title_height))
		      (height . ,longhorn:title_height)
		      (cursor . left_ptr)
		      (class . maximize-button))
		     ((background . ,min-image)
		      (right-edge . 39)
		      (top-edge . ,(- 0 longhorn:title_height))
		      (height . ,longhorn:title_height)
		      (cursor . left_ptr)
		      (class . iconify-button))
		     ((background . ,menu-image)
		      (left-edge . 1)
		      (top-edge . ,(- 0 longhorn:title_height))
		      (height . ,longhorn:title_height)
		      (cursor . hand2)
		      (class . menu-button))
		     ))
		     
     
     (transient-frame `(
			((background . ,top-left-image)
			 (top-edge . ,(- 0 longhorn:title_height))
			 (left-edge . -4)
			 (height . ,longhorn:title_height)
			 (class . title))
			((background . ,title-image)
			 (foreground . ,font-colors)
			 (text . ,window-name)
			 (x-justify . center)
			 (y-justify . center)
			 (left-edge . 18)
			 (right-edge . 18)
			 (top-edge . ,(- 0 longhorn:title_height))
			 (height . ,longhorn:title_height)
			 (cursor . left_ptr)
			 (class . title))
			((background . ,top-right-image)
			 (right-edge . -4)
			 (top-edge . ,(- 0 longhorn:title_height))
			 (height . ,longhorn:title_height)
			 (class . title))
			
			((background . ,border-left-image)
			 (left-edge . -4)
			 (top-edge . 0)
			 (bottom-edge . 0)
			 (class . left-border))
			((background . ,border-right-image)
			 (right-edge . -4)
			 (top-edge . 0)
			 (bottom-edge . 0)
			 (class . right-border))
			
			((background . ,bottom-left-image)
			 (left-edge . -4)
			 (bottom-edge . -4)
			 (class . bottom-left-corner))
			((background . ,bottom-middle-image)
			 (left-edge . 6)
			 (right-edge . 6)
			 (bottom-edge . -4)
			 (class . bottom-border))
			((background . ,bottom-right-image)
			 (right-edge . -4)
			 (bottom-edge . -4)
			 (class . bottom-right-corner))
			
			((background . ,close-image)
			 (right-edge . 1)
			 (top-edge . ,(- 0 longhorn:title_height))
			 (height . ,longhorn:title_height)
			 (cursor . left_ptr)
			 (class . close-button))
			((background . ,menu-image)
			 (left-edge . 1)
			 (top-edge . ,(- 0 longhorn:title_height))
			 (height . ,longhorn:title_height)
			 (cursor . hand2)
			 (class . menu-button))
			))
     
     (shaded-transient-frame `(
			       ((background . ,top-left-shaded-image)
				(top-edge . ,(- 0 longhorn:title_height))
				(left-edge . -4)
				(height . ,longhorn:title_height)
				(class . title))
			       ((background . ,title-image)
				(foreground . ,font-colors)
				(text . ,window-name)
				(x-justify . center)
				(y-justify . center)
				(left-edge . 18)
				(right-edge . 18)
				(top-edge . ,(- 0 longhorn:title_height))
				(height . ,longhorn:title_height)
				(cursor . left_ptr)
				(class . title))
			       ((background . ,top-right-shaded-image)
				(right-edge . -4)
				(top-edge . ,(- 0 longhorn:title_height))
				(height . ,longhorn:title_height)
				(class . title))
			       
			       ((background . ,close-image)
				(right-edge . 1)
				(top-edge . ,(- 0 longhorn:title_height))
				(height . ,longhorn:title_height)
				(cursor . left_ptr)
				(class . close-button))
			       ((background . ,menu-image)
				(left-edge . 1)
				(top-edge . ,(- 0 longhorn:title_height))
				(height . ,longhorn:title_height)
				(cursor . hand2)
				(class . menu-button))
			       ))
     
     )
  
  (add-frame-style 'longhorn
		   (lambda (w type)
		     (cond 
		      ((eq type 'transient) transient-frame)
		      ((eq type 'shaded-transient) shaded-transient-frame)
		      ((eq type 'shaded) shaded-frame)
		      ((eq type 'unframed) nil-frame)
		      (t frame)))
		   )
  )
  
